ErrorCode

Type Alias ErrorCode 

pub type ErrorCode = u32;
The error code that can be passed when aborting the send or receive side of the stream.

Some WebTransport implementations allow not specifying the error codes explicitly - this is equivalent to passing the error code 0.