pub type ErrorCode = u32;Expand description
The error code that can be passed when aborting the send or receive side of the stream.
Some WebTransport implementations allow not specifying the error codes
explicitly - this is equivalent to passing the error code 0.